Imports System
Imports System.Linq
Imports Microsoft.EntityFrameworkCore
Imports Microsoft.EntityFrameworkCore.Diagnostics
Imports UoWTestApp.Interfaces

Public Class UoWTestAppModelCore
    Inherits DbContext

    ' Your context has been configured to use a 'UoWTestAppModelCore' connection string from your application's 
    ' configuration file (App.config or Web.config). By default, this connection string targets the 
    ' 'UoWTestApp.UoWTestAppModelCore' database on your LocalDb instance. 
    ' 
    ' If you wish to target a different database and/or database provider, modify the 'UoWTestAppModelCore' 
    ' connection string in the application configuration file.
    Public Sub New()
    End Sub

    Public Sub New(ByVal sqlConnectionString As String)
        Me.New(New DbContextOptionsBuilder(Of UoWTestAppModelCore)().UseSqlServer(sqlConnectionString).Options)
    End Sub

    Friend Sub New(ByVal options As DbContextOptions)
        MyBase.New(options)
    End Sub

    Protected Overrides Sub OnConfiguring(ByVal optionsBuilder As DbContextOptionsBuilder)
        If Not optionsBuilder.IsConfigured Then
            optionsBuilder.UseSqlServer("Server=(localdb)\mssqllocaldb;Database=UoWTestApp.UoWTestAppModelCore;Trusted_Connection=False;").ConfigureWarnings(Function(warnings) warnings.[Throw](CoreEventId.IncludeIgnoredWarning))
        End If
    End Sub



    'Override for the SaveChanged Sub to deal with created and edit Interfaces
    Public Overrides Function SaveChanges() As Integer
        Dim objectStateEntries = ChangeTracker.Entries().Where(Function(e) TypeOf e.Entity Is model_base AndAlso e.State <> EntityState.Detached AndAlso e.State <> EntityState.Unchanged).ToList()
        For Each _Entry In objectStateEntries
            Dim entityBase = TryCast(_Entry.Entity, model_base)
            If entityBase Is Nothing Then Continue For
            Select Case _Entry.State
                Case EntityState.Deleted
                    Dim logicalDelete = TryCast(entityBase, IDelete)
                    If (logicalDelete IsNot Nothing) Then
                        _Entry.State = EntityState.Modified
                        logicalDelete.DeletedTimeStamp = DateTime.Now
                        logicalDelete.Deleted = True
                    End If
            End Select
        Next
        Return MyBase.SaveChanges()
    End Function

    Public Overridable Property Currencies As DbSet(Of Currency)

End Class